xcontext

package module
v0.0.0-...-50fdafb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 18, 2022 License: BSD-3-Clause Imports: 2 Imported by: 1

README

xcontext

xcontext implements functions that should be part of the standard library context package but are not.

Install

go get oss.terrastruct.com/xcontext

Documentation

Overview

Package xcontext implements functions that should be part of the standard library context package but are not.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WithoutCancel

func WithoutCancel(ctx context.Context) context.Context

WithoutCancel returns a context derived from ctx that may never be cancelled.

func WithoutValues

func WithoutValues(ctx context.Context) context.Context

WithoutValues creates a new context derived from ctx that does not inherit its values but does pass on cancellation.

Types

This section is empty.

Jump to