Documentation
¶
Overview ¶
Package xcontext implements functions that should be part of the standard library context package but are not.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WithoutCancel ¶
WithoutCancel returns a context derived from ctx that may never be cancelled.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.